@@ -337,12 +337,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_autoscaling
-import aws_cdk.aws_ec2
-import aws_cdk.aws_iam
-import aws_cdk.aws_sns
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_autoscaling as _aws_cdk_aws_autoscaling_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -365,12 +365,10 @@ class DockerVolumes:
         :stability: experimental
         '''
         if __debug__:
-            def stub(*, container_path: builtins.str, host_path: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6a7340e90cccad4868bbd85706a9e01f696a6d8037b67130d2ad8c0df2729c13)
             check_type(argname="argument container_path", value=container_path, expected_type=type_hints["container_path"])
             check_type(argname="argument host_path", value=host_path, expected_type=type_hints["host_path"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "container_path": container_path,
             "host_path": host_path,
         }
@@ -418,7 +416,7 @@ class DockerVolumes:
 
 
 class GitlabContainerRunner(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-gitlab-runner.GitlabContainerRunner",
 ):
@@ -429,28 +427,28 @@ class GitlabContainerRunner(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         gitlabtoken: builtins.str,
         concurrent_jobs: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
-        ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
         key_name: typing.Optional[builtins.str] = None,
         runner_description: typing.Optional[builtins.str] = None,
-        selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
         tag1: typing.Optional[builtins.str] = None,
         tag2: typing.Optional[builtins.str] = None,
         tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -478,32 +476,7 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                gitlabtoken: builtins.str,
-                concurrent_jobs: typing.Optional[jsii.Number] = None,
-                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
-                ebs_size: typing.Optional[jsii.Number] = None,
-                ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                ec2type: typing.Optional[builtins.str] = None,
-                gitlab_runner_image: typing.Optional[builtins.str] = None,
-                gitlaburl: typing.Optional[builtins.str] = None,
-                instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
-                key_name: typing.Optional[builtins.str] = None,
-                runner_description: typing.Optional[builtins.str] = None,
-                selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                spot_fleet: typing.Optional[builtins.bool] = None,
-                tag1: typing.Optional[builtins.str] = None,
-                tag2: typing.Optional[builtins.str] = None,
-                tag3: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                valid_until: typing.Optional[builtins.str] = None,
-                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3569128cd1ccb4f615528e61f1622fdbd79cb2ae3e5d8a3297d682bf482432fa)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabContainerRunnerProps(
@@ -533,7 +506,7 @@ class GitlabContainerRunner(
     @jsii.member(jsii_name="createUserData")
     def create_user_data(
         self,
-        props: typing.Union["GitlabContainerRunnerProps", typing.Dict[str, typing.Any]],
+        props: typing.Union["GitlabContainerRunnerProps", typing.Dict[builtins.str, typing.Any]],
         token_parameter_store_name: builtins.str,
     ) -> typing.List[builtins.str]:
         '''
@@ -545,18 +518,13 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                props: typing.Union[GitlabContainerRunnerProps, typing.Dict[str, typing.Any]],
-                token_parameter_store_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8bd058a7173e616aea7ec4839df2470f6ebe0b7b19ab8e14adc26a124919f645)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
             check_type(argname="argument token_parameter_store_name", value=token_parameter_store_name, expected_type=type_hints["token_parameter_store_name"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "createUserData", [props, token_parameter_store_name]))
 
     @jsii.member(jsii_name="expireAfter")
-    def expire_after(self, duration: aws_cdk.Duration) -> None:
+    def expire_after(self, duration: _aws_cdk_ceddda9d.Duration) -> None:
         '''(experimental) Add expire time function for spotfleet runner !!! .
 
         :param duration: - Block duration.
@@ -564,38 +532,36 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            def stub(duration: aws_cdk.Duration) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__573d5bebeef3dab5acf1ce20fe1bec4b423b45aa004fd1962be44c7be581f4d9)
             check_type(argname="argument duration", value=duration, expected_type=type_hints["duration"])
         return typing.cast(None, jsii.invoke(self, "expireAfter", [duration]))
 
     @builtins.property
     @jsii.member(jsii_name="defaultRunnerSG")
-    def default_runner_sg(self) -> aws_cdk.aws_ec2.ISecurityGroup:
+    def default_runner_sg(self) -> _aws_cdk_aws_ec2_ceddda9d.ISecurityGroup:
         '''(experimental) The EC2 runner's default SecurityGroup.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "defaultRunnerSG"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup, jsii.get(self, "defaultRunnerSG"))
 
     @builtins.property
     @jsii.member(jsii_name="runnerEc2")
-    def runner_ec2(self) -> aws_cdk.aws_ec2.IInstance:
+    def runner_ec2(self) -> _aws_cdk_aws_ec2_ceddda9d.IInstance:
         '''(experimental) This represents a Runner EC2 instance , !!! only support On-demand runner instance !!!
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.IInstance, jsii.get(self, "runnerEc2"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IInstance, jsii.get(self, "runnerEc2"))
 
     @builtins.property
     @jsii.member(jsii_name="runnerRole")
-    def runner_role(self) -> aws_cdk.aws_iam.IRole:
+    def runner_role(self) -> _aws_cdk_aws_iam_ceddda9d.IRole:
         '''(experimental) The IAM role assumed by the Runner instance .
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "runnerRole"))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IRole, jsii.get(self, "runnerRole"))
 
     @builtins.property
     @jsii.member(jsii_name="spotFleetInstanceId")
@@ -617,12 +583,12 @@ class GitlabContainerRunner(
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''(experimental) The EC2 runner's vpc.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -656,23 +622,23 @@ class GitlabContainerRunnerProps:
         *,
         gitlabtoken: builtins.str,
         concurrent_jobs: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
-        ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
         key_name: typing.Optional[builtins.str] = None,
         runner_description: typing.Optional[builtins.str] = None,
-        selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
         tag1: typing.Optional[builtins.str] = None,
         tag2: typing.Optional[builtins.str] = None,
         tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) GitlabContainerRunner Props.
 
@@ -699,32 +665,9 @@ class GitlabContainerRunnerProps:
         :stability: experimental
         '''
         if isinstance(vpc_subnet, dict):
-            vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+            vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
-            def stub(
-                *,
-                gitlabtoken: builtins.str,
-                concurrent_jobs: typing.Optional[jsii.Number] = None,
-                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
-                ebs_size: typing.Optional[jsii.Number] = None,
-                ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                ec2type: typing.Optional[builtins.str] = None,
-                gitlab_runner_image: typing.Optional[builtins.str] = None,
-                gitlaburl: typing.Optional[builtins.str] = None,
-                instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
-                key_name: typing.Optional[builtins.str] = None,
-                runner_description: typing.Optional[builtins.str] = None,
-                selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                spot_fleet: typing.Optional[builtins.bool] = None,
-                tag1: typing.Optional[builtins.str] = None,
-                tag2: typing.Optional[builtins.str] = None,
-                tag3: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                valid_until: typing.Optional[builtins.str] = None,
-                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655e745dbe)
             check_type(argname="argument gitlabtoken", value=gitlabtoken, expected_type=type_hints["gitlabtoken"])
             check_type(argname="argument concurrent_jobs", value=concurrent_jobs, expected_type=type_hints["concurrent_jobs"])
             check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
@@ -744,7 +687,7 @@ class GitlabContainerRunnerProps:
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
             check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "gitlabtoken": gitlabtoken,
         }
         if concurrent_jobs is not None:
@@ -853,7 +796,7 @@ class GitlabContainerRunnerProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def ec2iamrole(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def ec2iamrole(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''(experimental) IAM role for the Gitlab Runner Instance .
 
         :default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
@@ -871,7 +814,7 @@ class GitlabContainerRunnerProps:
             new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN', ec2iamrole: role });
         '''
         result = self._values.get("ec2iamrole")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     @builtins.property
     def ec2type(self) -> typing.Optional[builtins.str]:
@@ -958,7 +901,7 @@ class GitlabContainerRunnerProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def selfvpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def selfvpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''(experimental) VPC for the Gitlab Runner .
 
         :default: - new VPC will be created , 1 Vpc , 2 Public Subnet .
@@ -981,7 +924,7 @@ class GitlabContainerRunnerProps:
             new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN', selfvpc: newvpc });
         '''
         result = self._values.get("selfvpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def spot_fleet(self) -> typing.Optional[builtins.bool]:
@@ -1072,7 +1015,7 @@ class GitlabContainerRunnerProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def vpc_subnet(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def vpc_subnet(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''(experimental) VPC subnet for the spot fleet.
 
         :default: - public subnet
@@ -1097,7 +1040,7 @@ class GitlabContainerRunnerProps:
             });
         '''
         result = self._values.get("vpc_subnet")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1112,7 +1055,7 @@ class GitlabContainerRunnerProps:
 
 
 class GitlabRunnerAutoscaling(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-gitlab-runner.GitlabRunnerAutoscaling",
 ):
@@ -1123,24 +1066,24 @@ class GitlabRunnerAutoscaling(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
-        instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         instance_type: typing.Optional[builtins.str] = None,
         max_capacity: typing.Optional[jsii.Number] = None,
         min_capacity: typing.Optional[jsii.Number] = None,
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1164,28 +1107,7 @@ class GitlabRunnerAutoscaling(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                gitlab_token: builtins.str,
-                alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
-                desired_capacity: typing.Optional[jsii.Number] = None,
-                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
-                ebs_size: typing.Optional[jsii.Number] = None,
-                gitlab_runner_image: typing.Optional[builtins.str] = None,
-                gitlab_url: typing.Optional[builtins.str] = None,
-                instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                instance_type: typing.Optional[builtins.str] = None,
-                max_capacity: typing.Optional[jsii.Number] = None,
-                min_capacity: typing.Optional[jsii.Number] = None,
-                spot_instance: typing.Optional[builtins.bool] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e1346a7c57bd8e3d5b6fd96e74f7310063137cbf2338091d3cb96f36a1921a41)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
@@ -1215,18 +1137,18 @@ class GitlabRunnerAutoscaling(
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
-        instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         instance_type: typing.Optional[builtins.str] = None,
         max_capacity: typing.Optional[jsii.Number] = None,
         min_capacity: typing.Optional[jsii.Number] = None,
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> typing.List[builtins.str]:
         '''
         :param gitlab_token: (experimental) Gitlab token.
@@ -1271,48 +1193,48 @@ class GitlabRunnerAutoscaling(
 
     @builtins.property
     @jsii.member(jsii_name="autoscalingGroup")
-    def autoscaling_group(self) -> aws_cdk.aws_autoscaling.AutoScalingGroup:
+    def autoscaling_group(self) -> _aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup:
         '''(experimental) This represents a Runner Auto Scaling Group.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_autoscaling.AutoScalingGroup, jsii.get(self, "autoscalingGroup"))
+        return typing.cast(_aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup, jsii.get(self, "autoscalingGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="instanceRole")
-    def instance_role(self) -> aws_cdk.aws_iam.IRole:
+    def instance_role(self) -> _aws_cdk_aws_iam_ceddda9d.IRole:
         '''(experimental) The IAM role assumed by the Runner instance.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "instanceRole"))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IRole, jsii.get(self, "instanceRole"))
 
     @builtins.property
     @jsii.member(jsii_name="securityGroup")
-    def security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
+    def security_group(self) -> _aws_cdk_aws_ec2_ceddda9d.ISecurityGroup:
         '''(experimental) The EC2 runner's default SecurityGroup.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "securityGroup"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup, jsii.get(self, "securityGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="topicAlarm")
-    def topic_alarm(self) -> aws_cdk.aws_sns.ITopic:
+    def topic_alarm(self) -> _aws_cdk_aws_sns_ceddda9d.ITopic:
         '''(experimental) The SNS topic to suscribe alarms for EC2 runner's metrics.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_sns.ITopic, jsii.get(self, "topicAlarm"))
+        return typing.cast(_aws_cdk_aws_sns_ceddda9d.ITopic, jsii.get(self, "topicAlarm"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''(experimental) The EC2 runner's VPC.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -1343,18 +1265,18 @@ class GitlabRunnerAutoscalingProps:
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
-        instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         instance_type: typing.Optional[builtins.str] = None,
         max_capacity: typing.Optional[jsii.Number] = None,
         min_capacity: typing.Optional[jsii.Number] = None,
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) GitlabRunnerAutoscaling Props.
 
@@ -1377,28 +1299,9 @@ class GitlabRunnerAutoscalingProps:
         :stability: experimental
         '''
         if isinstance(vpc_subnet, dict):
-            vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+            vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
-            def stub(
-                *,
-                gitlab_token: builtins.str,
-                alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
-                desired_capacity: typing.Optional[jsii.Number] = None,
-                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
-                ebs_size: typing.Optional[jsii.Number] = None,
-                gitlab_runner_image: typing.Optional[builtins.str] = None,
-                gitlab_url: typing.Optional[builtins.str] = None,
-                instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                instance_type: typing.Optional[builtins.str] = None,
-                max_capacity: typing.Optional[jsii.Number] = None,
-                min_capacity: typing.Optional[jsii.Number] = None,
-                spot_instance: typing.Optional[builtins.bool] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__456bc54665e983cecf5d286556d3b391003886fdd1d6f537def2467508670cc9)
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
             check_type(argname="argument alarms", value=alarms, expected_type=type_hints["alarms"])
             check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
@@ -1414,7 +1317,7 @@ class GitlabRunnerAutoscalingProps:
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "gitlab_token": gitlab_token,
         }
         if alarms is not None:
@@ -1563,7 +1466,7 @@ class GitlabRunnerAutoscalingProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def instance_role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def instance_role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''(experimental) IAM role for the Gitlab Runner Instance .
 
         :default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
@@ -1581,7 +1484,7 @@ class GitlabRunnerAutoscalingProps:
             new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', instanceRole: role });
         '''
         result = self._values.get("instance_role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     @builtins.property
     def instance_type(self) -> typing.Optional[builtins.str]:
@@ -1651,7 +1554,7 @@ class GitlabRunnerAutoscalingProps:
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''(experimental) VPC for the Gitlab Runner .
 
         :default: - A new VPC will be created.
@@ -1674,10 +1577,10 @@ class GitlabRunnerAutoscalingProps:
             new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', vpc: newVpc });
         '''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
-    def vpc_subnet(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def vpc_subnet(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''(experimental) VPC subnet.
 
         :default: - private subnet
@@ -1702,7 +1605,7 @@ class GitlabRunnerAutoscalingProps:
             });
         '''
         result = self._values.get("vpc_subnet")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1750,3 +1653,120 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__6a7340e90cccad4868bbd85706a9e01f696a6d8037b67130d2ad8c0df2729c13(
+    *,
+    container_path: builtins.str,
+    host_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3569128cd1ccb4f615528e61f1622fdbd79cb2ae3e5d8a3297d682bf482432fa(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    gitlabtoken: builtins.str,
+    concurrent_jobs: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_size: typing.Optional[jsii.Number] = None,
+    ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    ec2type: typing.Optional[builtins.str] = None,
+    gitlab_runner_image: typing.Optional[builtins.str] = None,
+    gitlaburl: typing.Optional[builtins.str] = None,
+    instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
+    key_name: typing.Optional[builtins.str] = None,
+    runner_description: typing.Optional[builtins.str] = None,
+    selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    spot_fleet: typing.Optional[builtins.bool] = None,
+    tag1: typing.Optional[builtins.str] = None,
+    tag2: typing.Optional[builtins.str] = None,
+    tag3: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    valid_until: typing.Optional[builtins.str] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8bd058a7173e616aea7ec4839df2470f6ebe0b7b19ab8e14adc26a124919f645(
+    props: typing.Union[GitlabContainerRunnerProps, typing.Dict[builtins.str, typing.Any]],
+    token_parameter_store_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__573d5bebeef3dab5acf1ce20fe1bec4b423b45aa004fd1962be44c7be581f4d9(
+    duration: _aws_cdk_ceddda9d.Duration,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655e745dbe(
+    *,
+    gitlabtoken: builtins.str,
+    concurrent_jobs: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_size: typing.Optional[jsii.Number] = None,
+    ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    ec2type: typing.Optional[builtins.str] = None,
+    gitlab_runner_image: typing.Optional[builtins.str] = None,
+    gitlaburl: typing.Optional[builtins.str] = None,
+    instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
+    key_name: typing.Optional[builtins.str] = None,
+    runner_description: typing.Optional[builtins.str] = None,
+    selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    spot_fleet: typing.Optional[builtins.bool] = None,
+    tag1: typing.Optional[builtins.str] = None,
+    tag2: typing.Optional[builtins.str] = None,
+    tag3: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    valid_until: typing.Optional[builtins.str] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e1346a7c57bd8e3d5b6fd96e74f7310063137cbf2338091d3cb96f36a1921a41(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    gitlab_token: builtins.str,
+    alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
+    desired_capacity: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_size: typing.Optional[jsii.Number] = None,
+    gitlab_runner_image: typing.Optional[builtins.str] = None,
+    gitlab_url: typing.Optional[builtins.str] = None,
+    instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    instance_type: typing.Optional[builtins.str] = None,
+    max_capacity: typing.Optional[jsii.Number] = None,
+    min_capacity: typing.Optional[jsii.Number] = None,
+    spot_instance: typing.Optional[builtins.bool] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__456bc54665e983cecf5d286556d3b391003886fdd1d6f537def2467508670cc9(
+    *,
+    gitlab_token: builtins.str,
+    alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
+    desired_capacity: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_size: typing.Optional[jsii.Number] = None,
+    gitlab_runner_image: typing.Optional[builtins.str] = None,
+    gitlab_url: typing.Optional[builtins.str] = None,
+    instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    instance_type: typing.Optional[builtins.str] = None,
+    max_capacity: typing.Optional[jsii.Number] = None,
+    min_capacity: typing.Optional[jsii.Number] = None,
+    spot_instance: typing.Optional[builtins.bool] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
